@@ -107,8 +107,12 @@ gtk2hs_closure_marshal(GClosure *closure,
     WHEN_DEBUG(g_debug("gtk2hs_closure_marshal(%p): about to rts_evalIO", hc->callback));
     
     /* perform the call */
+    #if __GLASGOW_HASKELL__>=704
+    rts_evalIO(&cap, rts_apply(CAP (HaskellObj)runIO_closure, call),&ret);
+    #else
     cap=rts_evalIO(CAP rts_apply(CAP (HaskellObj)runIO_closure, call),&ret);
-    
+    #endif
+
     WHEN_DEBUG(g_debug("gtk2hs_closure_marshal(%p): about to rts_checkSchedStatus", hc->callback));
     
     /* barf if anything went wrong */
@@ -199,8 +203,8 @@ gtk2hs_value_as_haskellobj(const GValue *value) {
         return rts_mkPtr(CAP g_value_get_pointer(value));
     case G_TYPE_BOXED:
         return rts_mkPtr(CAP g_value_get_boxed(value));
-/*    case G_TYPE_PARAM:
-        return g_value_get_param(value); */
+    case G_TYPE_PARAM:
+        return rts_mkPtr(CAP g_value_get_param(value));
     case G_TYPE_OBJECT:
         return rts_mkPtr(CAP g_value_get_object(value));
     }
